==> attal_0.8.orig.tar.gz: attal-0.8/i18n/it/attal_ai_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AiInterface</name>
    <message>
        <source>Attal: IA client</source>
        <translation>Attal: client AI</translation>
    </message>
    <message>
        <source>Log level : Verbose</source>
        <translation>Livello di log: Prolisso</translation>
    </message>
    <message>
        <source>Verbose</source>
        <translation>Prolisso</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critico</translation>
    </message>
    <message>
        <source>Quiet</source>
        <translation>Calmo</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">Collega</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Disconnessione</translation>
    </message>
    <message>
        <source>Log Level</source>
        <translation>Livello di log</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Non posso connettermi</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Sei già connesso al server. Per piacere prima disconnettiti</translation>
    </message>
    <message>
        <source>Log level : Normal</source>
        <translation>Livello di log: Normale</translation>
    </message>
    <message>
        <source>Log level : Critical</source>
        <translation>Livello di log: Critico</translation>
    </message>
    <message>
        <source>Log level : Quiet</source>
        <translation>Livello di log: Calmo</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Collegamento al server</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Collegamento al server</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Disconnessione</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation>
Collegamento al server</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Host :</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Porta :</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nome :</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Collega</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
</TS>

==> attal_0.9.2.orig.tar.gz: attal-0.9.2/i18n/it/attal_ai_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AiInterface</name>
    <message>
        <source>Attal: IA client</source>
        <translation>Attal: client AI</translation>
    </message>
    <message>
        <source>Log level : Verbose</source>
        <translation>Livello di log: Prolisso</translation>
    </message>
    <message>
        <source>Verbose</source>
        <translation>Prolisso</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critico</translation>
    </message>
    <message>
        <source>Quiet</source>
        <translation>Calmo</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">Collega</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Disconnessione</translation>
    </message>
    <message>
        <source>Log Level</source>
        <translation>Livello di log</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Non posso connettermi</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Sei già connesso al server. Per piacere prima disconnettiti</translation>
    </message>
    <message>
        <source>Log level : Normal</source>
        <translation>Livello di log: Normale</translation>
    </message>
    <message>
        <source>Log level : Critical</source>
        <translation>Livello di log: Critico</translation>
    </message>
    <message>
        <source>Log level : Quiet</source>
        <translation>Livello di log: Calmo</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Collegamento al server</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Collegamento al server</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Disconnessione</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Non posso caricare il tema</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Il tema </translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation> non è stato caricato con successo</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation>
Collegamento al server</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Host :</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Porta :</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nome :</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Collega</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
</TS>
